beniget: Extract semantic information about static Python code
==============================================================

Description
-----------

Extract semantic information about static Python code

License
-------

BSD 3-Clause

Upstream Contact
----------------

https://pypi.org/project/beniget/

